==> relations-0.0.1.tar.gz: lib/view/stage_items/stage_entity.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import '../../bloc/bloc.dart';
import '../../bloc/graph_bloc.dart';

// Base class for entites existing in the stage.
abstract class StageEntity extends StatefulWidget {
  StageEntity({
    Key key
  }) : super(key: key);
}

abstract class StageEntityState<Entity extends StageEntity> extends State<Entity> with TickerProviderStateMixin {
  
  Animation<double> scaleAnimation;
  AnimationController scaleAnimController;

  double stageInverseScale = 1.0;
  double stageScale = 1.0;

  GraphBloc graphBloc;
  StageBloc stageBloc;

  StreamSubscription<Matrix4> stageTransformSubscription;

  void updateOnScale(double newScale);

  void onStageTransformChange(Matrix4 transform);

  void startAnim(double startScale, double endScale) {
    final animating = scaleAnimController?.isAnimating ?? true;
    if (animating) {
      return;
    }

    scaleAnimation = Tween<double>(
      begin: startScale,
      end: endScale,
    ).animate(scaleAnimController);

    scaleAnimation.addListener(onAnimate);
    scaleAnimController.fling();
    /// print("anim started");
  }

  void onAnimate() {
    setState(() {
      updateOnScale(scaleAnimation.value);
    });
    if (!scaleAnimController.isAnimating) {
      scaleAnimation?.removeListener(onAnimate);
      scaleAnimation = null;
      scaleAnimController.reset();
    }
  }

  @override
  void initState() {
    super.initState();

    stageBloc = BlocProvider.of<StageBloc>(context);
    graphBloc = BlocProvider.of<GraphBloc>(context);
    
    // Need this to prevent displaying "scale up" behavior on rebuild
    updateOnScale(stageBloc.currentState.stageScale);
    stageTransformSubscription = stageBloc.stageTransformNotifier?.listen(onStageTransformChange);

    scaleAnimController = AnimationController(
      vsync: this,
      duration:  Duration(milliseconds: 500)
    );
  }

  @override
  void dispose() {
    scaleAnimController.dispose();
    stageTransformSubscription?.cancel();   
    super.dispose();
    
    
  }

}

==> relations-0.0.4.tar.gz: lib/view/stage_items/stage_entity.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import '../../bloc/bloc.dart';
import '../../bloc/graph_bloc.dart';

// Base class for entites existing in the stage.
abstract class StageEntity extends StatefulWidget {
  StageEntity({Key key}) : super(key: key);
}

abstract class StageEntityState<Entity extends StageEntity>
    extends State<Entity> with TickerProviderStateMixin {
  Animation<double> scaleAnimation;
  AnimationController scaleAnimController;

  double stageInverseScale = 1.0;
  double stageScale = 1.0;

  GraphBloc graphBloc;
  StageBloc stageBloc;

  StreamSubscription<Matrix4> stageTransformSubscription;

  void updateOnScale(double newScale);

  void onStageTransformChange(Matrix4 transform);

  void startAnim(double startScale, double endScale) {
    final animating = scaleAnimController?.isAnimating ?? true;
    if (animating) {
      return;
    }

    scaleAnimation = Tween<double>(
      begin: startScale,
      end: endScale,
    ).animate(scaleAnimController);

    scaleAnimation.addListener(onAnimate);
    scaleAnimController.fling();

    /// print("anim started");
  }

  void onAnimate() {
    setState(() {
      updateOnScale(scaleAnimation.value);
    });
    if (!scaleAnimController.isAnimating) {
      scaleAnimation?.removeListener(onAnimate);
      scaleAnimation = null;
      scaleAnimController.reset();
    }
  }

  @override
  void initState() {
    super.initState();

    stageBloc = BlocProvider.of<StageBloc>(context);
    graphBloc = BlocProvider.of<GraphBloc>(context);

    // Need this to prevent displaying "scale up" behavior on rebuild
    updateOnScale(stageBloc.currentState.stageScale);
    stageTransformSubscription =
        stageBloc.stageTransformNotifier?.listen(onStageTransformChange);

    scaleAnimController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 500));
  }

  @override
  void dispose() {
    scaleAnimController.dispose();
    stageTransformSubscription?.cancel();
    super.dispose();
  }
}
